pub struct IgnoreFile {
pub path: PathBuf,
pub applies_in: Option<PathBuf>,
pub applies_to: Option<ProjectType>,
}Expand description
An ignore file.
This records both the path to the ignore file and some basic metadata about it: which project
type it applies to if any, and which subtree it applies in if any (None = global ignore file).
Fields
path: PathBufThe path to the ignore file.
applies_in: Option<PathBuf>The path to the subtree the ignore file applies to, or None for global ignores.
applies_to: Option<ProjectType>Which project type the ignore file applies to, or was found through.